package jp.ac.takushoku_u.cs;

/**
* NegativeMatrixSizeException饹Υĥޥȥꥯ
* 褦ȤȤ򼨤˥ޤ
* @version 1.2
* @author  ͵(Kasajima Hiroshi)
*/
/*
* ǽ 2004ǯ1209
*/

public class NegativeMatrixSizeException extends NegativeSizeException{

/**
* åʤ NegativeMatrixSizeException ۤޤ
*/
	public NegativeMatrixSizeException(){
		super();
	}
	
/**
* ꤷܺ٥å NegativeMatrixSizeException ۤޤ
* @param s ܺ٥å
*/
	public NegativeMatrixSizeException(String s){
		super(s);
	}
}